@@ -3,5 +3,5 @@ if [ -z "$PYTHON_EXE" ]; then
     PYTHON_EXE="/usr/bin/python"
 fi
 
-prefix="/usr/local"
+prefix="/usr"
 LC_ALL=C PYTHONPATH="${prefix}/share/vdsm" "$PYTHON_EXE" ../tests/testrunner.py $@
